@@ -297,9 +297,9 @@ class TestElementShape(unittest.TestCase):
         s = SimpleLine(fill='red')
         self.assertEqual(repr(s), "SimpleLine(x1=0.0, y1=0.0, x2=0.0, y2=0.0, fill='#ff0000')")
         s = Polygon(fill='red')
-        self.assertEqual(repr(s), "Polygon(points=(''), fill='#ff0000')")
+        self.assertEqual(repr(s), "Polygon(points='', fill='#ff0000')")
         s = Polyline(fill='red')
-        self.assertEqual(repr(s), "Polyline(points=(''), fill='#ff0000')")
+        self.assertEqual(repr(s), "Polyline(points='', fill='#ff0000')")
         s = Path(fill='red')
         self.assertEqual(repr(s), "Path(fill='#ff0000')")
 
@@ -553,6 +553,27 @@ class TestElementShape(unittest.TestCase):
         m = SVG.parse(q)
         self.assertEqual(len(m), 0)
 
+    def test_rect_strict(self):
+        values = {
+            'tag': 'rect',
+            'rx': "-4",
+            'x': "50",
+            'y': "51",
+            'width': "20",
+            'height': "10"
+        }
+        e = Rect(values)
+        e2 = Rect(50, 51, 20, 10)
+        self.assertEqual(e, e2)
+
+        e3 = Rect(values)
+        e3._strict = False  # unstrict rx-negative rectangles, have scooped corners.
+        self.assertNotEqual(e3, e2)
+
+        values['ry'] = 4
+        e4 = Rect(values)
+        self.assertEqual(e, e4)
+
     def test_shape_npoints(self):
         import numpy as np
         shapes = [
